@@ -1486,8 +1486,15 @@ glutInit();
 glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_ALPHA);
 if (not glutGet(GLUT_DISPLAY_MODE_POSSIBLE))
 {
-   warn "glutInitDisplayMode not possible, exiting quietly";
-   exit 0;
+   warn "glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_ALPHA) not possible";
+   warn "...trying without GLUT_ALPHA";
+   # try without GLUT_ALPHA
+   glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH);
+   if (not glutGet(GLUT_DISPLAY_MODE_POSSIBLE))
+   {
+      warn "glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH) not possible, exiting quietly";
+      exit 0;
+   }
 }
 #glutInitDisplayString("rgb alpha>=0 double depth");
 
